@@ -229,13 +229,24 @@ Scaffold::Handler::ExtDirect - A handler for Ext.Direct RPC requests
     configs => {
         doc_rootp => 'html',
     },
-    locations => {
-        '/'            => 'App::Main',
-        '/robots.txt'  => 'Scaffold::Handler::Robots',
-        '/favicon.ico' => 'Scaffold::Handler::Favicon',
-        '/static'      => 'Scaffold::Handler::Static',
-        '/rpc'         => 'Scaffold::Handler::ExtDirect',
-    },
+    locations => [
+        {
+            route   => qr{^/$},
+            handler => 'App::Main'
+        },{ 
+            route   => qr{^/robots.txt$},
+            handler => 'Scaffold::Handler::Robots',
+        },{
+            route   => qr{^/favicon.ico$},
+            handler => 'Scaffold::Handler::Favicon',
+        },{
+            route   => qr{^/static/(.*)$},
+            handler => 'Scaffold::Handler::Static',
+        },{
+            route   => qr{^/rpc$},
+            handler => 'Scaffold::Handler::ExtDirect',
+        }
+    ] 
  );
 
 =head1 DESCRIPTION
@@ -263,6 +274,7 @@ Scaffold::Handler::ExtDirect - A handler for Ext.Direct RPC requests
  Scaffold::Render
  Scaffold::Render::Default
  Scaffold::Render::TT
+ Scaffold::Routes
  Scaffold::Server
  Scaffold::Session::Manager
  Scaffold::Stash
@@ -282,7 +294,7 @@ Scaffold::Handler::ExtDirect - A handler for Ext.Direct RPC requests
 
 =head1 AUTHOR
 
-Kevin L. Esteb, E<lt>kesteb@wsipc.orgE<gt>
+Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
