@@ -50,13 +50,24 @@ Scaffold::Handler::ExtPoll - A handler to for the Ext.direct poller
     configs => {
         doc_rootp => 'html',
     },
-    locations => {
-        '/'            => 'App::Main',
-        '/robots.txt'  => 'Scaffold::Handler::Robots',
-        '/favicon.ico' => 'Scaffold::Handler::Favicon',
-        '/static'      => 'Scaffold::Handler::Static',
-        '/poll'        => 'Scaffold::Handler::ExtPoll',
-    },
+    locations => [
+        {
+            route   => qr{^/$},
+            handler => 'App::Main'
+        },{ 
+            route   => qr{^/robots.txt$},
+            handler => 'Scaffold::Handler::Robots',
+        },{
+            route   => qr{^/favicon.ico$},
+            handler => 'Scaffold::Handler::Favicon',
+        },{
+            route   => qr{^/static/(.*)$},
+            handler => 'Scaffold::Handler::Static',
+        },{
+            route   => qr{^/poll$},
+            handler => 'Scaffold::Handler::ExtPoll',
+        }
+    ] 
  );
 
 =head1 DESCRIPTION
@@ -103,7 +114,7 @@ Scaffold::Handler::ExtPoll - A handler to for the Ext.direct poller
 
 =head1 AUTHOR
 
-Kevin L. Esteb, E<lt>kesteb@wsipc.orgE<gt>
+Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
